#
# spec file for package tallow
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tallow
Version:        21+git20200213.865ec91
Release:        bp154.1.28
Summary:        Temporary IP address ban issuance daemon
License:        GPL-3.0-or-later
URL:            https://github.com/clearlinux/tallow
Source:         tallow-%{version}.tar.xz
Requires:       ipset
Requires:       iptables
#For systemd macros:
PreReq:         coreutils
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libjson-c-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  rubygem(ronn)

%description
Tallow is a fail2ban/lard replacement that uses systemd's native
journal API to scan for attempted SSH logins, and issues temporary IP
address bans for clients that violate certain login patterns.

This is not a security application! Tallow is meant to reduce log
clutter and system resource usage at the cost of denying access to
potentially valid users.

%prep
%setup -q

%build
./autogen.sh
%configure
export LANG=en_US.UTF-8
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_sysconfdir}
touch %{buildroot}%{_sysconfdir}/tallow.conf
rm -rf %{buildroot}%{_datadir}/doc/tallow
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system
install -m 644 data/tallow.service %{buildroot}%{_prefix}/lib/systemd/system/
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rctallow
# For customer provided *.json files:
mkdir -p %{buildroot}%{_sysconfdir}/tallow

%pre
%service_add_pre tallow.service

%post
%service_add_post tallow.service

%preun
%service_del_preun tallow.service

%postun
%service_del_postun tallow.service

%files
%license COPYING
%doc README.md tallow.conf
%dir %{_sysconfdir}/tallow
%{_sbindir}/tallow
%{_sbindir}/rctallow
%{_prefix}/lib/systemd/system/tallow.service
%{_mandir}/man1/tallow.1%{?ext_man}
%{_mandir}/man5/tallow.conf.5%{?ext_man}
%{_mandir}/man5/tallow.patterns.5%{?ext_man}
%dir %{_datadir}/tallow
%{_datadir}/tallow/sshd.json
%ghost %{_sysconfdir}/tallow.conf

%changelog
* Thu Feb 13 2020 kukuk@suse.de
- Update to version 21+git20200213.865ec91:
  * Add tallow.patterns man page
  * Add extra path for firewall-cmd
- Drop 0001-Add-extra-path-for-firewall-cmd.patch, accepted upstream
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Thu Nov 28 2019 Thorsten Kukuk <kukuk@suse.com>
- 0001-Add-extra-path-for-firewall-cmd.patch: firewall-cmd can be
  in a different path than ipset/iptables
* Wed Nov 27 2019 kukuk@suse.de
- Update to version 19+git20191106.4b071b0:
  * Need configure in this workflow.
  * Fix dependency.
  * Add github workflow integration.
* Tue Nov  5 2019 kukuk@suse.de
- Update to version 19+git20191104.5dfb982:
  * v19
  * Fixed signedness.
* Tue Oct 29 2019 kukuk@suse.de
- Update to version 18+git20191028.83201e8:
  * v18
  * Hide unwanted firewalld-cmd error messages.
  * v17
  * Add firewalld support
  * Fix command order in tallow.conf man page
  * Add json-c to travis.
  * make older compilers a bit happier
  * add dovecot as postfix auth backend parsing
* Sat Aug 17 2019 kukuk@suse.de
- Update to version 16+git20190425.e4b3977:
  * Ensure we don't replay old events.
  * Add example whitelist defaults.
* Tue Jun  4 2019 kukuk@suse.de
- Add PreRequires for systemd macros
* Sun Feb 24 2019 kukuk@suse.de
- Update to version 16+git20190219.35182b8:
  * Force insert iptables rules as rule #1.
  * Debug: print path to skipped file, not the other one.
* Thu Feb  7 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
- Wrap description.
* Wed Feb  6 2019 kukuk@suse.de
- Add requires for iptables and ipset
* Wed Feb  6 2019 kukuk@suse.de
- Update to version 16+git20190123.0a0a912:
  * Move src files to /src/.
  * Move man pages to /man/ folder.
* Wed Feb  6 2019 kukuk@suse.de
- Initial version (v16)
